@@ -524,35 +524,27 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 				menu_item=gtk_image_menu_item_new_with_label(appName);
 				if (iconSize!=0)
 				{
-					gint width,height;
+					GdkPixbuf *icon;
+					GtkIconInfo *icon_info;
+					GtkWidget *image;
 					icon_theme = gtk_icon_theme_get_default ();
-					icon=gtk_icon_theme_load_icon(icon_theme,iconName,iconSize,0,NULL);
+					icon_info = gtk_icon_theme_lookup_icon(icon_theme,iconName,iconSize,0);
+					if (icon_info==NULL)
+						icon=NULL;
+					else
+						icon=gdk_pixbuf_new_from_file_at_size(gtk_icon_info_get_filename(icon_info),iconSize,iconSize,NULL);
 					if (icon==NULL)
 					{
-						icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",iconSize,0,NULL);
+						icon_info = gtk_icon_theme_lookup_icon(icon_theme,"qgn_list_gene_default_app",iconSize,0);
+						icon = gdk_pixbuf_new_from_file_at_size(gtk_icon_info_get_filename(icon_info),iconSize,iconSize,NULL);
 					}
-					width=gdk_pixbuf_get_width(icon);
-					height=gdk_pixbuf_get_height(icon);
-					if ((width!=iconSize)&&(height!=iconSize))
-					{
-						if (width>height)
-						{
-							gint scale=(((gdouble)height/(gdouble)width)*iconSize);
-							icon=gdk_pixbuf_scale_simple(icon,iconSize,scale,GDK_INTERP_NEAREST);
-						}
-						else if (height>width)
-						{
-							gint scale=(((gdouble)width/(gdouble)height)*iconSize);
-							icon=gdk_pixbuf_scale_simple(icon,scale,iconSize,GDK_INTERP_NEAREST);
-						}
-						else
-						{
-							icon=gdk_pixbuf_scale_simple(icon,iconSize,iconSize,GDK_INTERP_NEAREST);
-						}
-					}
-					icon_image=gtk_image_new_from_pixbuf(icon);
+
+					image=gtk_image_new_from_pixbuf(icon);
+
 					g_object_unref(G_OBJECT(icon));
-					gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),icon_image);
+					gtk_icon_info_free(icon_info);
+
+					gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menu_item),image);
 				}
 				if (!systemBool)
 					gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",fontString,"' foreground='#",colourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
@@ -677,7 +669,7 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   g_signal_connect(G_OBJECT(button),"toggled",G_CALLBACK(popup_menu),navigator_plugin);
   
   gtk_widget_set_size_request (button, 80, 80);
-  gtk_widget_set_name (button, "hildon-navigator-button-one");
+  //gtk_widget_set_name (button, "hildon-navigator-button-one");
 
   gtk_widget_show_all (button);
 
@@ -687,6 +679,14 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   navigator_plugin->menu=gtk_menu_new();
   create_menu(navigator_plugin);
 
+  GdkColor color;
+
+  color.red = 65535;
+  color.blue = 0;
+  color.green = 0;
+  gtk_widget_modify_bg(navigator_plugin->menu,GTK_STATE_NORMAL,&color);
+
+
   navigator_plugin->context=osso_initialize("personalmenu","0.9",TRUE,NULL);
   result=osso_rpc_set_cb_f(navigator_plugin->context,"com.nokia.personalmenu","/com/nokia/personalmenu","com.nokia.personalmenu",&dbus_req_handler,navigator_plugin);
 
